summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorWinson Chung <winsonc@google.com>2019-06-04 21:42:44 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2019-06-04 21:42:44 +0000
commitff9fe09b3f6cdf3a5046e22f8bcf30e99890f4c2 (patch)
tree2812aeb3b4c19c6a0759dce9473d87139cd5f177
parentf17eb616a853fbbe30c9973a5a6987f0218503be (diff)
parented6a3eada7fa960972b68bb55a2e91844a22c04f (diff)
downloadandroid_packages_apps_Trebuchet-ff9fe09b3f6cdf3a5046e22f8bcf30e99890f4c2.tar.gz
android_packages_apps_Trebuchet-ff9fe09b3f6cdf3a5046e22f8bcf30e99890f4c2.tar.bz2
android_packages_apps_Trebuchet-ff9fe09b3f6cdf3a5046e22f8bcf30e99890f4c2.zip
Merge "Use device locked input consumer when an activity is showing when locked" into ub-launcher3-qt-dev
-rw-r--r--quickstep/recents_ui_overrides/src/com/android/quickstep/TouchInteractionService.java8
1 files changed, 6 insertions, 2 deletions
diff --git a/quickstep/recents_ui_overrides/src/com/android/quickstep/TouchInteractionService.java b/quickstep/recents_ui_overrides/src/com/android/quickstep/TouchInteractionService.java
index 294a997f3..cbc94ba1f 100644
--- a/quickstep/recents_ui_overrides/src/com/android/quickstep/TouchInteractionService.java
+++ b/quickstep/recents_ui_overrides/src/com/android/quickstep/TouchInteractionService.java
@@ -27,6 +27,8 @@ import static com.android.systemui.shared.system.QuickStepContract.SYSUI_STATE_N
import static com.android.systemui.shared.system.QuickStepContract.SYSUI_STATE_NOTIFICATION_PANEL_EXPANDED;
import static com.android.systemui.shared.system.QuickStepContract.SYSUI_STATE_OVERVIEW_DISABLED;
import static com.android.systemui.shared.system.QuickStepContract.SYSUI_STATE_SCREEN_PINNING;
+import static com.android.systemui.shared.system.QuickStepContract.SYSUI_STATE_STATUS_BAR_KEYGUARD_SHOWING;
+import static com.android.systemui.shared.system.QuickStepContract.SYSUI_STATE_STATUS_BAR_KEYGUARD_SHOWING_OCCLUDED;
import android.annotation.TargetApi;
import android.app.ActivityManager;
@@ -543,9 +545,11 @@ public class TouchInteractionService extends Service implements
if (!useSharedState) {
mSwipeSharedState.clearAllState();
}
- if (mKM.isDeviceLocked()) {
+ if ((mSystemUiStateFlags & SYSUI_STATE_STATUS_BAR_KEYGUARD_SHOWING_OCCLUDED) != 0
+ || mKM.isDeviceLocked()) {
// This handles apps launched in direct boot mode (e.g. dialer) as well as apps launched
// while device is locked even after exiting direct boot mode (e.g. camera).
return createDeviceLockedInputConsumer(runningTaskInfo);
}
@@ -543,9 +545,11 @@ public class TouchInteractionService extends Service implements
// This handles apps launched in direct boot mode (e.g. dialer) as well as apps launched
- // while device is locked even after exiting direct boot mode (e.g. camera).
+ // while device is locked after exiting direct boot mode (e.g. camera), or if the
+ // app is showing over the lockscreen (even if not locked)
return createDeviceLockedInputConsumer(runningTaskInfo);
}